==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/admin/config_plugins.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright  2008 MyBB Group, All Rights Reserved
 * 
 * $Id: config_plugins.lang.php 4304 2009-01-02 01:11:56Z chris $
 */

$l['plugins'] = "Plugins";
$l['plugins_desc'] = "This section allows you to activate, deactivate, and manage the plugins that you have uploaded to your forum's <strong>inc/plugins</strong> directory. To hide a plugin from view, but not lose any stored information from it, click the Deactivate link.";
$l['plugin_updates'] = "Plugin Updates";
$l['plugin_updates_desc'] = "This section allows you to check for updates on all your plugins.";

$l['plugin'] = "Plugin";
$l['your_version'] = "Your Version";
$l['latest_version'] = "Latest Version";
$l['download'] = "Download";
$l['deactivate'] = "Deactivate";
$l['activate'] = "Activate";
$l['install_and_activate'] = "Install &amp; Activate";
$l['uninstall'] = "Uninstall";
$l['created_by'] = "Created by";
$l['no_plugins'] = "There are no plugins on your forum at this time.";

$l['plugin_incompatible'] = "This plugin is incompatible with MyBB {1}";

$l['error_vcheck_no_supported_plugins'] = "None of the plugins installed support version checking.";
$l['error_vcheck_communications_problem'] = "There was a problem communicating with the mod version server. Please try again in a few minutes.";
$l['error_no_input'] = "Error code 1: No input specified.";
$l['error_no_pids'] = "Error code 2: No plugin ids specified.";
$l['error_communication_problem'] = "There was a problem communicating with the mod version server.";
$l['error_invalid_plugin'] = "The selected plugin does not exist.";

$l['success_plugins_up_to_date'] = "Congratulations, all of your plugins are up to date.";
$l['success_plugin_activated'] = "The selected plugin has been activated successfully.";
$l['success_plugin_deactivated'] = "The selected plugin has been deactivated successfully.";
$l['success_plugin_installed'] = "The selected plugin has been installed and activated successfully.";
$l['success_plugin_uninstalled'] = "The selected plugin has been uninstalled successfully.";
?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/admin/config_plugins.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 * 
 * $Id: config_plugins.lang.php 5297 2010-12-28 22:01:14Z Tomm $
 */

$l['plugins'] = "Plugins";
$l['plugins_desc'] = "This section allows you to activate, deactivate, and manage the plugins that you have uploaded to your forum's <strong>inc/plugins</strong> directory. To hide a plugin from view, but not lose any stored information from it, click the Deactivate link.";
$l['plugin_updates'] = "Plugin Updates";
$l['plugin_updates_desc'] = "This section allows you to check for updates on all your plugins.";
$l['browse_plugins'] = "Browse Plugins";
$l['browse_plugins_desc'] = "Here you may browse the official MyBB modifications site for plugins compatible with your series of MyBB.";
$l['browse_all_plugins'] = "Browse All Plugins";

$l['plugin'] = "Plugin";
$l['your_version'] = "Your Version";
$l['latest_version'] = "Latest Version";
$l['download'] = "Download";
$l['deactivate'] = "Deactivate";
$l['activate'] = "Activate";
$l['install_and_activate'] = "Install &amp; Activate";
$l['uninstall'] = "Uninstall";
$l['created_by'] = "Created by";
$l['no_plugins'] = "There are no plugins on your forum at this time.";

$l['plugin_incompatible'] = "This plugin is incompatible with MyBB {1}";

$l['recommended_plugins_for_mybb'] = "Recommended Plugins for MyBB {1}";
$l['browse_results_for_mybb'] = "Browse Results for MyBB {1}";
$l['search_for_plugins'] = "Search for Plugins";
$l['search'] = "Search";

$l['error_vcheck_no_supported_plugins'] = "None of the plugins installed support version checking.";
$l['error_vcheck_communications_problem'] = "There was a problem communicating with the MyBB modifications version server. Please try again in a few minutes.";
$l['error_no_input'] = "Error code 1: No input specified.";
$l['error_no_pids'] = "Error code 2: No plugin ids specified.";
$l['error_communication_problem'] = "There was a problem communicating with the MyBB modifications server. Please try again in a few minutes.";
$l['error_invalid_plugin'] = "The selected plugin does not exist.";
$l['error_no_results_found'] = "No results were found for the specified keywords.";

$l['success_plugins_up_to_date'] = "Congratulations, all of your plugins are up to date.";
$l['success_plugin_activated'] = "The selected plugin has been activated successfully.";
$l['success_plugin_deactivated'] = "The selected plugin has been deactivated successfully.";
$l['success_plugin_installed'] = "The selected plugin has been installed and activated successfully.";
$l['success_plugin_uninstalled'] = "The selected plugin has been uninstalled successfully.";
?>
